All Classes and Interfaces

Class
Description
An artifact transform that wraps a file into a directory
A service class for downloading files
Describes a downloadable file
A Gradle plugin to add Jextract to the build
DSL extension to configure which Jextract installation should be used by the Jextract plugin
Holds common properties for Jextract-related tasks, does nothing itself
Configuration of a Jextract installation that can be used by this task
Configuration of a local Jextract installation
Configuration of a downloadable Jextract version
Helpers for consistent paths and filenames for Jextract, depending on version and platform
Uses Jextract to dump all included symbols of a library header into an arg file
The dSL extension to configure the jextract plugin
Task that uses Jextract to generate Java bindings for given C headers
Custom dependencies for native libraries to generate bindings for using Jextract
A build service that downloads and manages Jextract installation.
Configuration parameters for the service
Creates a new JMOD archive.
A configuration for a library to be generated by Jextract
Configures the native library path for Java execution.
Describes a platform where jextract can be installed and run.
Describes a processor architecture for a given platform.
Describes an operating system for a given platform.
Configures a source Set to include libraries generated by Jextract
A configuration for included definitions in a library to be generated by Jextract